@@ -5,12 +5,15 @@ from xml.etree import ElementTree
 import html
 from wand.image import Image
 from wand.exceptions import PolicyError, WandRuntimeError
-from elifecleaner import LOGGER, pdf_utils, zip_lib
+from elifecleaner import LOGGER, pdf_utils, utils, zip_lib
 
 
 # flag for whether to try and repair XML if it encounters a ParseError
 REPAIR_XML = True
 
+# acceptable file extensions for an art_file
+ART_FILE_EXTENSIONS = ["doc", "docx", "tex"]
+
 
 def check_ejp_zip(zip_file, tmp_dir):
     "check contents of ejp zip file"
@@ -34,6 +37,8 @@ def check_files(files, asset_file_name_map, identifier):
     extra_files = check_extra_files(files, asset_file_name_map, identifier)
     # check for out of sequence files by name
     check_missing_files_by_name(files, identifier)
+    # check the art file type
+    check_art_file(files, identifier)
     return True
 
 
@@ -232,6 +237,29 @@ def find_missing_value_by_sequence(values, match_pattern):
     return missing_files
 
 
+def check_art_file(files, identifier):
+    "check for an art file and it is an acceptable type"
+    art_files = [
+        file_data for file_data in files if file_data.get("file_type") == "art_file"
+    ]
+    file_extensions = [
+        file_data.get("upload_file_nm").rsplit(".", 1)[-1]
+        for file_data in art_files
+        if file_data.get("upload_file_nm")
+    ]
+    # convert values to lowercase when comparing
+    good_file_extensions = [
+        extension
+        for extension in file_extensions
+        if extension.lower() in ART_FILE_EXTENSIONS
+    ]
+    if not art_files or not good_file_extensions:
+        LOGGER.warning(
+            "%s could not find a word or latex article file in the package",
+            identifier,
+        )
+
+
 def article_xml_asset(asset_file_name_map):
     """
     find the article XML file name,
@@ -253,6 +281,13 @@ def parse_article_xml(xml_file):
         xml_string = open_file.read()
         # unescape any HTML entities to avoid undefined entity XML exceptions later
         xml_string = html_entity_unescape(xml_string)
+        # fix XML-incompatible character entities
+        if utils.match_control_character_entities(xml_string):
+            LOGGER.info(
+                "Replacing character entities in the XML string: %s"
+                % utils.match_control_character_entities(xml_string)
+            )
+            xml_string = utils.replace_control_character_entities(xml_string)
         try:
             return ElementTree.fromstring(xml_string)
         except ElementTree.ParseError:
